Action

Enum Action 

pub enum Action<S = String> {
Show 37 variants Bold, Br, Color(Color), Dest(Dest<S>), Expire(Expire<S>), Filter(Filter<S>), Font(Font<S>), Frame(Frame<S>), Gauge(Gauge<S>), Heading(Heading), Highlight, Hr, Hyperlink(Hyperlink<S>), Image(Image<S>), Italic, Music(Music<S>), MusicOff, MxpOff, NoBr, P, Password, Relocate(Relocate<S>), Reset, SBr, Send(Send<S>), Small, Sound(Sound<S>), SoundOff, Stat(Stat<S>), Strikeout, StyleVersion(StyleVersion<S>), Support(Support<S>), Tt, Underline, User, Var(Var<S>), Version,
}
Effect caused by an element. Created by applying Arguments to an element AtomicTag.

Variants



Bold

<BOLD>: Make text bold.



Br

<BR>: Insert a hard line break.



Color(Color)

<COLOR>: Change text color.



Dest(Dest<S>)

<DEST>: Set destination frame.



Expire(Expire<S>)

<EXPIRE>: Expire links.



Filter(Filter<S>)

<FILTER>: Set file filter.



Font(Font<S>)

<FONT>: Change text font.



Frame(Frame<S>)

<FRAME>: Create a frame window.



Gauge(Gauge<S>)

<GAUGE>: Display an MXP entity value as a gauge.



Heading(Heading)

<H{N}>: Format text as a heading.



Highlight

<HIGH>: Highlight text.



Hr

<HR>: Insert a horizontal rule.

<A>: Hyperlink.



Image(Image<S>)

<IMAGE>: Display an image.



Italic

<ITALIC>: Make text italic.



Music(Music<S>)

<MUSIC>: Play music.



MusicOff

<MUSIC OFF>: Stop music.



MxpOff

<MXP OFF>: MXP control command. This is an unofficial extension to the MXP protocol.



NoBr

<NOBR>: Ignore next newline.



P

<P>: Insert a paragraph break.



Password

<PASSWORD>: Prompt client to send user password.



Relocate(Relocate<S>)

<RELOCATE>: Prompt client to switch to a new network connection.



Reset

<RESET>: Close all OPEN tags. This is an unofficial extension to the MXP protocol.



SBr

<SBR>: Insert a soft linebreak.



Send(Send<S>)

<Send>: Turn text into a link that sends a command to the world.



Small

<SMALL>: Display text in a smaller size.



Sound(Sound<S>)

<SOUND>: Play a sound file.



SoundOff

<SOUND OFF>: Stop all sound.



Stat(Stat<S>)

<STAT>: Display an MXP entity value on the status bar.



Strikeout

<STRIKEOUT>: Strike-out the text.



StyleVersion(StyleVersion<S>)

<VERSION>: The client should cache this style-sheet version number and return it when requested by a plain <VERSION> request.



Support(Support<S>)

<SUPPORT>: Prompt client to respond with the commands that it supports.



Tt

<TT>: Display text in a non-proportional font.



Underline

<UNDERLINE>: Underline text.



User

<USER>: Prompt client to send username.



Var(Var<S>)

<VAR>: Set an MXP variable.



Version

<VERSION>: Prompt client to respond with its client and version of MXP.

Implementations

Source

impl<S: IntoOwnedString> Action<S>

pub fn into_owned(self) -> Action<String>

Source

impl<S> Action<S>

pub fn map_text<F, T>(self, f: F) -> Action<T>
where F: FnMut(S) -> T,

Applies a type transformation to all text, returning a new struct.