ActionKind

Enum ActionKind 

pub enum ActionKind {
Show 39 variants Bold, Br, Color, Dest, Expire, Filter, Font, Frame, Gauge, H1, H2, H3, H4, H5, H6, Highlight, Hr, Hyperlink, Image, Italic, Music, Mxp, NoBr, P, Password, Relocate, Reset, SBr, Send, Small, Sound, Stat, Strikeout, Support, Tt, Underline, User, Var, Version,
}
Type of effect caused by an Action.

Variants



Bold

<BOLD>: Make text bold.



Br

<BR>: Insert a hard line break.



Color

<COLOR>: Change text color.



Dest

<DEST>: Set destination frame.



Expire

<EXPIRE>: Expire links.



Filter

<FILTER>: Set file filter.



Font

<FONT>: Change text font.



Frame

<FRAME>: Create a frame window.



Gauge

<GAUGE>: Display an MXP entity value as a gauge.



H1

Level 1 heading.



H2

Level 2 heading.



H3

Level 3 heading.



H4

Level 4 heading.



H5

Level 5 heading.



H6

Level 6 heading.



Highlight

<HIGH>: Highlight text.



Hr

<HR>: Insert a horizontal rule.

<A>: Hyperlink.



Image

<IMAGE>: Display an image.



Italic

<ITALIC>: Make text italic.



Music

<MUSIC>: Play or stop music.



Mxp

<MXP OFF>: MXP control command. This is an unofficial extension to the MXP protocol.



NoBr

<NOBR>: Ignore next newline.



P

<P>: Insert a paragraph break.



Password

<PASSWORD>: Prompt client to send user password.



Relocate

<RELOCATE>: Prompt client to switch to a new network connection.



Reset

<RESET>: Close all OPEN tags. This is an unofficial extension to the MXP protocol.



SBr

<SBR>: Insert a soft linebreak.



Send

<Send>: Turn text into a link that sends a command to the world.



Small

<SMALL>: Display text in a smaller size.



Sound

<SOUND>: Play or stop a sound file.



Stat

<STAT>: Display an MXP entity value on the status bar.



Strikeout

<STRIKEOUT>: Strike-out the text.



Support

<SUPPORT>: Prompt client to respond with the commands that it supports.



Tt

<TT>: Display text in a non-proportional font.



Underline

<UNDERLINE>: Underline text.



User

<USER>: Prompt client to send username.



Var

<VAR>: Set an MXP variable.



Version

<VERSION>: Prompt client to respond with its client and version of MXP.

Implementations

Source

impl ActionKind

pub const fn is_command(self) -> bool

Returns true if this is a command tag. Command tags do not have content, so they have no closing tag.

pub const fn is_open(self) -> bool

Returns true if the action can be used if the MXP line Mode is OPEN.

The following actions are OPEN: