Gauge

Struct Gauge 

pub struct Gauge<S = String> {
    pub entity: S,
    pub max: Option<S>,
    pub caption: Option<S>,
    pub color: Option<RgbColor>,
}
Displays an MXP entity value as a gauge.

See MXP specification: <GAUGE>.

Examples

use mxp::RgbColor;

assert_eq!(
    "<GAUGE Hp MAX=HpMax CAPTION=Health COLOR=red>".parse::<mxp::Gauge>(),
    Ok(mxp::Gauge {
        entity: "Hp".into(),
        max: Some("HpMax".into()),
        caption: Some("Health".into()),
        color: Some(RgbColor::hex(0xFF0000)),
    }),
);

Fields

entity: S

Name of the entity to use as gauge data.

max: Option<S>

Name of the entity to use for the maximum value of the gauge.

caption: Option<S>

Optional text to display on the gauge.

color: Option<RgbColor>

Color of the gauge bar.

Implementations

Source

impl<S> Gauge<S>

pub fn map_text<T, F>(self, f: F) -> Gauge<T>
where F: FnMut(S) -> T,

Applies a type transformation to all text, returning a new struct.

Source

impl<S: IntoOwnedString> Gauge<S>

pub fn into_owned(self) -> Gauge<String>

Source

impl<S: AsRef<str>> Gauge<S>

pub fn borrow_text(&self) -> Gauge<&str>

Returns a new struct that borrows text from this one.