Relocate

Struct Relocate 

pub struct Relocate<S = String> {
    pub hostname: S,
    pub port: u16,
    pub quiet: bool,
}
Closes the current MUD connection and causes a new connect to open on a new server.

See MXP specification: <RELOCATE>.

Examples

assert_eq!(
    "<RELOCATE new.server.com 1000>".parse::<mxp::Relocate>(),
    Ok(mxp::Relocate {
        hostname: "new.server.com".into(),
        port: 1000,
        quiet: false,
    }),
);

Fields

hostname: S

Hostname of the new connection.

port: u16

Port of the new connection.

quiet: bool

The optional keyword QUIET can be used to suppress further output from the MUD. When the closing </RELOCATE> tag is used, MUD output is resumed.

Implementations

Source

impl<S> Relocate<S>

pub fn map_text<T, F>(self, f: F) -> Relocate<T>
where F: FnOnce(S) -> T,

Applies a type transformation to all text, returning a new struct.

Source

impl<S: IntoOwnedString> Relocate<S>

Source

impl<S: AsRef<str>> Relocate<S>

pub fn borrow_text(&self) -> Relocate<&str>

Returns a new struct that borrows text from this one.