Sound

Struct Sound 

pub struct Sound<S = String> {
    pub fname: S,
    pub volume: u8,
    pub repeat: AudioRepetition,
    pub priority: u8,
    pub class: Option<S>,
    pub url: Option<S>,
}
Sound triggers are WAV format files intended for sound effects.

See MXP specification: <SOUND> and the MSP (Mud Sound Protocol) specification.

Examples

use mxp::AudioRepetition;

assert_eq!(
    "<SOUND 'weather/rain.wav' V=80 L=3 P=10 T=combat U='http://example.org:5000/sound'>".parse::<mxp::Sound>(),
    Ok(mxp::Sound {
        fname: "weather/rain.wav".into(),
        volume: 80,
        repeat: AudioRepetition::Count(3.try_into().unwrap()),
        priority: 10,
        class: Some("combat".into()),
        url: Some("http://example.org:5000/sound".into()),
    }),
);

Fields

fname: S

File name. May contain wildcards. If no extension is specified, “.wav” should be assumed.

volume: u8

Volume between 0 and 100.

repeat: AudioRepetition

Repeat behavior.

priority: u8

This parameter applies when some sound is playing and another request arrives. Then, if new request has higher (but NOT equal) priority than the one that’s currently being played, old sound must be stopped and the new sound starts playing instead. In the case of a tie, the sound that is already playing wins.

class: Option<S>

Type of sound, e.g. combat, zone, death, clan. Case-insensitive. This parameter was intended to provide a way to group sounds into subfolders within the main sound directory.

url: Option<S>

Specifies the URL of the sound file. This allows downloading files from the MUD server. Client should always look in local directories first, and only download the file if it’s not available locally.

Implementations

Source

impl<S: AsRef<str>> Sound<S>

pub fn is_off(&self) -> bool

Returns true if this command is a <SOUND OFF> command, causing sounds to stop rather than triggering a sound.

Source

impl<S> Sound<S>

pub fn map_text<T, F>(self, f: F) -> Sound<T>
where F: FnMut(S) -> T,

Applies a type transformation to all text, returning a new struct.

Source

impl<S: IntoOwnedString> Sound<S>

pub fn into_owned(self) -> Sound<String>

Source

impl<S: AsRef<str>> Sound<S>

pub fn borrow_text(&self) -> Sound<&str>

Returns a new struct that borrows text from this one.