pub struct Stat<S = String> {
pub entity: S,
pub max: Option<S>,
pub caption: Option<S>,
}Expand description
Displays an MXP entity value as status bar text.
See MXP specification: <STAT>.
Examples
use mxp::RgbColor;
assert_eq!(
"<Stat Hp MAX=HpMax CAPTION=Health>".parse::<mxp::Stat>(),
Ok(mxp::Stat {
entity: "Hp".into(),
max: Some("HpMax".into()),
caption: Some("Health".into()),
}),
);Fields
entity: SName of the entity to use as text data.
max: Option<S>Name of the entity to use for the maximum value of the data.
caption: Option<S>Optional caption text.
Implementations