Support

Struct Support 

pub struct Support<S = String> {
    pub questions: Vec<S>,
}
Determines exactly which tags are supported by the client.

See MXP specification: <SUPPORT>.

Examples

assert_eq!(
    "<SUPPORT 'color.*' send.expire image>".parse::<mxp::Support>(),
    Ok(mxp::Support {
        questions: vec!["color.*".into(), "send.expire".into(), "image".into()],
    }),
);

Fields

questions: Vec<S>

Implementations

Source

impl<S> Support<S>

pub fn map_text<T, F>(self, f: F) -> Support<T>
where F: FnMut(S) -> T,

Applies a type transformation to all text, returning a new struct.

pub fn iter(&self) -> Iter<'_, S>

Alias for self.questions.iter().

pub fn respond( &self, supported: FlagSet<ActionKind>, ) -> SupportResponse<Iter<'_, S>>
where S: AsRef<str>,

Constructs a SupportResponse from this struct’s questions.

Source

impl<S: IntoOwnedString> Support<S>