Module entity

Module entity 

Entity and associated types.

Structs

Entity
Stores information from the MUD (MUD variables).
EntityEntry
This struct is created by EntityMap::define. See its documentation for more.
EntityInfo
This struct is created by EntityMap::published. See its documentation for more.
EntityMap
Stores all entities for the current environment, both MXP-defined entities (as Entity) and global XML entities (as &'static str).

Enums

DecodedEntity
A decoded MXP entity, either standard or server-defined.
EntityKeyword
Keywords for <!ENTITY> tags.
EntityVisibility
Visibility of an Entity, as defined by the server.

Type Aliases

PublishedIter
Type alias for the iterator returned by EntityMap::published.