EntityKeyword

Enum EntityKeyword 

pub enum EntityKeyword {
    Private,
    Publish,
    Delete,
    Add,
    Remove,
}
Keywords for <!ENTITY> tags.

Variants



Private

PRIVATE entities cannot be queried by the MUD client. They are completely hidden.



Publish

PUBLISH entities can be used by the client to produce a list of MUD Server variables to be accessed by the player.



Delete

To delete an entity, use the DELETE argument. Setting an entity to a empty value does not delete it.



Add

The ADD argument causes the Value to be added as a new item in a string list. So, it is appended to the existing value of the variable. String lists are values separated by the '|' character.



Remove

The REMOVE argument causes the Value to be removed from the existing string list.