EntityVisibility

Enum EntityVisibility 

pub enum EntityVisibility {
    Default,
    Private,
    Publish,
}
Visibility of an Entity, as defined by the server.

See MXP specification: Entities.

Variants



Default

By default, MXP entities can be queried, but are not listed.



Private

Private entities cannot be queried by the MUD client. They are completely hidden.



Publish

Published entities can be used by the client to produce a list of MUD Server variables to be access by the player.