ElementDefinition

Struct ElementDefinition 

pub struct ElementDefinition<'a> {
    pub name: &'a str,
    pub element: Option<Element>,
}
Syntax tree of an element definition from the server, in the form of <!ELEMENT {name} ...>.

See MXP specification: Elements.

Full definition:

<!ELEMENT
    Name
    [Definition]
    [ATT=attribute-list]
    [TAG=tag]
    [FLAG=flags]
    [OPEN]
    [DELETE]
    [EMPTY]
>

Fields

name: &'a str

Name of the element.

element: Option<Element>

Definition of the element, or None if this is a DELETE instruction.