TagBuilder

Struct TagBuilder 

pub struct TagBuilder<'a> { /* private fields */ }
Utility for servers to build custom opening tags.

Examples

let mut builder = mxp::node::TagBuilder::new("monster");
builder
    .push("hostile")
    .push_all(&["Minotaur", "old veteran"])
    .insert("hp", "150");
let tag = builder.build();
assert_eq!(
    tag.to_string(),
    r#"<monster hostile Minotaur "old veteran" hp=150>"#
);

Implementations

Source

impl<'a> TagBuilder<'a>

A server-side utility for building opening tags.

pub fn new(name: &'a str) -> Self

Creates a builder for an opening tag with the specified element name.

pub fn build(self) -> TagOpen<'a, Cow<'a, str>>

Converts this builder into a finalized TagOpen.

pub fn push(&mut self, value: &'a str) -> &mut Self

Adds a positional argument or keyword without escaping special characters.

pub fn escape_and_push(&mut self, value: &'a str) -> &mut Self

Adds a positional argument or keyword after escaping special characters.

pub fn push_all<I>(&mut self, iter: I) -> &mut Self
where I: IntoIterator, I::Item: Borrow<&'a str>,

Adds multiple positional arguments or keywords without escaping special characters.

pub fn escape_and_push_all<I>(&mut self, iter: I) -> &mut Self
where I: IntoIterator, I::Item: Borrow<&'a str>,

Adds multiple positional arguments or keywords after escaping special characters.

pub fn insert(&mut self, name: &'a str, value: &'a str) -> &mut Self

Inserts a named argument without escaping special characters.

pub fn escape_and_insert(&mut self, name: &'a str, value: &'a str) -> &mut Self

Inserts a named argument after escaping special characters.

pub fn insert_all<I, K, V>(&mut self, iter: I) -> &mut Self
where I: IntoIterator, I::Item: Borrow<(K, V)>, K: Borrow<&'a str>, V: Borrow<&'a str>,

Inserts multiple named arguments without escaping special characters.

pub fn escape_and_insert_all<I, K, V>(&mut self, iter: I) -> &mut Self
where I: IntoIterator, I::Item: Borrow<(K, V)>, K: Borrow<&'a str>, V: Borrow<&'a str>,

Inserts multiple named arguments after escaping special characters.

pub fn set_empty(&mut self, empty: bool) -> &mut Self

Tag will end with a '/' character, indicating that is empty.