pub struct Dimension<T = u32> {
pub amount: T,
pub unit: DimensionUnit,
}Expand description
A measurement of screen space, specified as a pixel amount, a percentage, or an amount of
character widths, as determined by the DimensionUnit.
Fields
amount: Tunit: DimensionUnitImplementations
Sourceimpl<T> Dimension<T>
impl<T> Dimension<T>
Sourcepub const fn pixels(amount: T) -> Self
pub const fn pixels(amount: T) -> Self
Constructs a Dimension for the specified amount in pixels (DimensionUnit::Pixel).
Sourcepub const fn character_spacing(amount: T) -> Self
pub const fn character_spacing(amount: T) -> Self
Constructs a Dimension for the specified amount in character spacing
(DimensionUnit::CharacterSpacing).
Sourcepub const fn percentage(amount: T) -> Self
pub const fn percentage(amount: T) -> Self
Constructs a Dimension for the specified amount in screen percentage
(DimensionUnit::Percentage).