Mode

Struct Mode 

pub struct Mode(pub u8);
Mode defined by a line tag.

See MXP specification: MXP Line Tags.

Tuple Fields

0: u8

Implementations

Source

impl Mode

pub const OPEN: Self

Only MXP commands in the OPEN category are allowed. When a newline is received from the MUD, the mode reverts back to the default mode. This mode starts as the default mode.

pub const SECURE: Self

All tags and commands in MXP are allowed within the line. When a newline is received from the MUD, the mode reverts back to the default mode.

pub const LOCKED: Self

No MXP or HTML commands are allowed in the line. The line is not parsed for any tags at all. When a newline is received from the MUD, the mode reverts back to the Default mode.

pub const RESET: Self

Close all open tags. Set active mode and default mode to OPEN. Set text color and properties to default.

pub const SECURE_ONCE: Self

Set SECURE mode for the next tag only. Must be immediately followed by a '<' character to start a tag.

pub const PERM_OPEN: Self

Set OPEN mode. Mode remains in effect until changed. OPEN mode becomes the new default mode.

pub const PERM_SECURE: Self

Set SECURE mode. Mode remains in effect until changed. SECURE mode becomes the new default mode.

pub const PERM_LOCKED: Self

Set LOCKED mode. Mode remains in effect until changed. LOCKED mode becomes the new default mode.

pub const ROOM_NAME: Self

The line is parsed as the name of a room.

pub const ROOM_DESC: Self

The line is parsed as the description of a room.

pub const ROOM_EXITS: Self

The line is parsed as the name of a room.

pub const WELCOME_TEXT: Self

This text is sent from the MUD at the beginning of a session to welcome the user to the MUD.

pub const USER_DEFINED_MIN: Self

Minimum value of a user-defined line mode. See Mode::is_user_defined.

pub const USER_DEFINED_MAX: Self

Maximum value of a user-defined line mode. See Mode::is_user_defined.

Source

impl Mode

pub const fn is_open(self) -> bool

When this mode is active, only MXP commands in the OPEN category are allowed.

The following modes are OPEN:

pub const fn is_locked(self) -> bool

When this mode is active, MXP tags should not be parsed.

The following modes are locked:

pub const fn is_automapping(self) -> bool

When this mode is active, the line is tagged for automappers.

Line modes between 10 ROOM_NAME and 19 WELCOME_TEXT are reserved for automappers.

pub const fn parse_as(self) -> Option<ParseAs>

How the line should be parsed by an automapper. This only applies to ROOM_NAME, Mode::ROOM_DESC, and ROOM_EXITS.

pub const fn is_user_defined(self) -> bool

When this mode is active, the line is tagged for a MUD-specific purpose. The tag must have been previously defined using an MXP definition command to tell the client how to handle the line.

A common use for these is to tag various chat channels to allow client-side filtering or redirection of the text.

User-defined tags must be between 20 (USER_DEFINED_MIN) and 99 (USER_DEFINED_MAX).