pub enum ParseAs {
RoomName,
RoomDesc,
RoomExit,
RoomNum,
Prompt,
}Expand description
The MUD server can tag a line to be parsed in a specific way by the client.
Variants
RoomName
The text for the element is parsed by the automapper as the name of a room.
RoomDesc
The text for the element is parsed by the automapper as the description of a room.
RoomExit
The text for the element is parsed by the automapper as exits for the room.
RoomNum
The text for the element is parsed by the automapper as a room number.
Prompt
The text for the element is parsed by as a MUD Prompt.