Atomic elements defined by the MXP standard.
Structs
- Color
- Sets the color of the text.
- Dest
- Positions text at a certain position in a frame.
- Expire
- Removes previously displayed links. For example, when moving to a new room, links from the previous room description are no longer valid and need to be removed.
- Filter
- Defines a graphics format and provides a client plugin module that converts the MUD-specific format to a standard GIF or BMP format.
- Font
- Changes the font for subsequent text.
- Frame
- A separate browser window region with its own HTML document.
- Gauge
- Displays an MXP entity value as a gauge.
- Hyperlink
- Opens a web page in the user’s web browser.
- Image
- Displays an inline graphics image.
- Music
- Music triggers are typically background MID (MIDI) files. Only one music trigger can be active at once.
- Relocate
- Closes the current MUD connection and causes a new connect to open on a new server.
- Send
- Specifies that a span of text can be clicked on to cause an action.
- Send
Menu - This struct is created by
Send::menu. See its documentation for more. - Send
Menu Item - This struct is created by
Send::menu. See its documentation for more. - Sound
- Sound triggers are WAV format files intended for sound effects.
- Stat
- Displays an MXP entity value as status bar text.
- Style
Version - A MUD sets a style-sheet version number by sending the
<VERSION styleversion>tag to the client. - Support
- Determines exactly which tags are supported by the client.
- Var
- The
<VAR>tag is just like the<!ENTITY>tag, except that the value of the variable is placed between the<VAR>and</VAR>tags, and this value is displayed to the user.
Enums
- Audio
Repetition - Specifies the number of times a sound/music file should be played.
- Font
Style - Font modifier applied by the
colorargument of aFonttag. - Frame
Action - Action to apply to a
Frame. - Frame
Align - Alignment of an on-screen item.
- Frame
Layout - Alignment and position of a
Frame, which may either be an external (floating) frame or an internal (docked) frame. - Heading
- Sets text heading level.