pub struct Gauge<S = String> {
pub entity: S,
pub max: Option<S>,
pub caption: Option<S>,
pub color: Option<RgbColor>,
}Expand description
Displays an MXP entity value as a gauge.
See MXP specification: <GAUGE>.
Examples
use mxp::RgbColor;
assert_eq!(
"<GAUGE Hp MAX=HpMax CAPTION=Health COLOR=red>".parse::<mxp::Gauge>(),
Ok(mxp::Gauge {
entity: "Hp".into(),
max: Some("HpMax".into()),
caption: Some("Health".into()),
color: Some(RgbColor::hex(0xFF0000)),
}),
);Fields
entity: SName of the entity to use as gauge data.
max: Option<S>Name of the entity to use for the maximum value of the gauge.
caption: Option<S>Optional text to display on the gauge.
color: Option<RgbColor>Color of the gauge bar.
Implementations