pub struct Relocate<S = String> {
pub hostname: S,
pub port: u16,
pub quiet: bool,
}Expand description
Closes the current MUD connection and causes a new connect to open on a new server.
See MXP specification: <RELOCATE>.
Examples
assert_eq!(
"<RELOCATE new.server.com 1000>".parse::<mxp::Relocate>(),
Ok(mxp::Relocate {
hostname: "new.server.com".into(),
port: 1000,
quiet: false,
}),
);Fields
hostname: SHostname of the new connection.
port: u16Port of the new connection.
quiet: boolThe optional keyword QUIET can be used to suppress further output from the MUD.
When the closing </RELOCATE> tag is used, MUD output is resumed.
Implementations