pub struct Support<S = String> {
pub questions: Vec<S>,
}Expand description
Determines exactly which tags are supported by the client.
See MXP specification: <SUPPORT>.
Examples
assert_eq!(
"<SUPPORT 'color.*' send.expire image>".parse::<mxp::Support>(),
Ok(mxp::Support {
questions: vec!["color.*".into(), "send.expire".into(), "image".into()],
}),
);Fields
questions: Vec<S>Implementations
Sourceimpl<S> Support<S>
impl<S> Support<S>
Sourcepub fn map_text<T, F>(self, f: F) -> Support<T>where
F: FnMut(S) -> T,
pub fn map_text<T, F>(self, f: F) -> Support<T>where
F: FnMut(S) -> T,
Applies a type transformation to all text, returning a new struct.
Sourcepub fn respond(
&self,
supported: FlagSet<ActionKind>,
) -> SupportResponse<Iter<'_, S>>
pub fn respond( &self, supported: FlagSet<ActionKind>, ) -> SupportResponse<Iter<'_, S>>
Constructs a SupportResponse from this struct’s questions.