pub enum DimensionUnit {
Pixel = 0,
Percentage = 37,
CharacterSpacing = 99,
}Expand description
Specifies the units of a Dimension.
Variants
Pixel = 0
The amount is measured in pixels. For example, a frame with LEFT=50 TOP=25 starts 50
pixels from the left edge of the screen and 25 pixels from the top edge of the screen.
Percentage = 37
The amount is measured as a percentage. For example, a frame with LEFT="50%" TOP="25%"
starts halfway across the screen and 25% of the way from the top to the bottom.
CharacterSpacing = 99
The amount is measured in character size. For example, a frame with LEFT="50c" TOP="25c"
starts 50 character spacings from the left side of the screen (using the width of the
character X if it is a proportional font), and 25 character spacings from the top of the
screen (using the height of the capital X character).