pub struct ElementDefinition<'a> {
pub name: &'a str,
pub element: Option<Element>,
}Expand description
Syntax tree of an element definition from the server, in the form of <!ELEMENT {name} ...>.
See MXP specification: Elements.
Full definition:
<!ELEMENT
Name
[Definition]
[ATT=attribute-list]
[TAG=tag]
[FLAG=flags]
[OPEN]
[DELETE]
[EMPTY]
>Fields
name: &'a strName of the element.
element: Option<Element>Definition of the element, or None if this is a DELETE instruction.